WebPlatformSslAuthError class

Web implementation of PlatformSslAuthError.

Browser iframe APIs do not expose recoverable TLS certificate decisions to embedded Flutter Web apps. This type keeps the platform interface surface explicit while reporting the platform limitation at the call site.

Constructors

WebPlatformSslAuthError({String description = 'Recoverable SSL certificate decisions are not exposed by browser iframe APIs.'})
Creates a WebPlatformSslAuthError.

Properties

certificate → X509Certificate?
The certificate associated with this error.
finalinherited
description → String
A human-presentable description for a given error.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → Future<void>
Instructs the WebView that encountered the SSL certificate error to terminate communication with the server.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
proceed() → Future<void>
Instructs the WebView that encountered the SSL certificate error to ignore the error and continue communicating with the server.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited