proceed method

  1. @override
Future<void> proceed()

Instructs the WebView that encountered the SSL certificate error to ignore the error and continue communicating with the server.

Warning: Warning: Calling proceed in a production environment is strongly discouraged, as an invalid SSL certificate means that the connection is not secure, so proceeding can expose users to security and privacy risks.

Implementation

@override
Future<void> proceed() async {
  throw UnsupportedError(_unsupportedMessage);
}