WebWebViewWidgetCreationParams class

Web-specific creation parameters for WebWebViewWidget.

Annotations

Constructors

WebWebViewWidgetCreationParams({Key? key, required PlatformWebViewController controller, TextDirection layoutDirection = TextDirection.ltr, Set<Factory<OneSequenceGestureRecognizer>> gestureRecognizers = const <Factory<OneSequenceGestureRecognizer>>{}})
Creates a new WebWebViewWidgetCreationParams.
const
WebWebViewWidgetCreationParams.fromPlatformWebViewWidgetCreationParams(PlatformWebViewWidgetCreationParams params)
Creates a WebWebViewWidgetCreationParams from generic params.

Properties

controller → PlatformWebViewController
The PlatformWebViewController that allows controlling the native web view.
finalinherited
gestureRecognizers → Set<Factory<OneSequenceGestureRecognizer>>
The gestureRecognizers specifies which gestures should be consumed by the web view.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
layoutDirection → TextDirection
The layout direction to use for the embedded WebView.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited